@@ -8,12 +8,15 @@ test_that("route works", {
   # Input checks
   expect_error(route(origin = c(1, 2, 3), destination = poi), "'origin' must be an sf object.")
   expect_error(route(origin = c("character", NA), destination = poi), "'origin' must be an sf object.")
-  expect_error(route(origin = poi, destination = poi, mode = "not_a_mode"))
-  expect_error(route(origin = poi, destination = poi, type = "not_a_type"))
-  expect_error(route(origin = poi, destination = poi, vehicle_type = "not_a_vehicle_type"))
+  expect_error(route(origin = poi, destination = poi, transport_mode = "not_a_transport_mode"))
+  expect_error(route(origin = poi, destination = poi, routing_mode = "not_a_routing_mode"))
   expect_error(route(origin = poi, destination = poi, traffic = "not_a_bool"), "'traffic' must be a 'boolean' value.")
   expect_error(route(origin = poi, destination = poi, url_only = "not_a_bool"), "'url_only' must be a 'boolean' value.")
 
+  # Deprecated
+  expect_warning(route(origin = poi, destination = poi, type = "fast", url_only = TRUE))
+  expect_warning(route(origin = poi, destination = poi, mode = "car", url_only = TRUE))
+
   # Test with API response mock
   with_mock(
     "hereR:::.get_content" = function(url) {hereR:::mock$route_response},
